package com.logicbig.example;

import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.core.Context;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Enumeration;

@Path("/")
public class ExampleResource {
    @Context
    private ServletConfig servletConfig;
    @Context
    private ServletContext servletContext;
    @Context
    private HttpServletRequest httpServletRequest;
    @Context
    private HttpServletResponse httpServletResponse;

    @GET
    @Path("/test")
    public void handleRequest() throws IOException {
        System.out.println("-- in resource method --");
        printServletConfigInfo();
        printServletContextInfo();
        printServletRequestInfo();
        //committing response using HttpServletResponse
        httpServletResponse.getWriter().write("Test response");
        httpServletResponse.getWriter().flush();
    }

    private void printServletRequestInfo() {
        System.out.println("-- Servlet Request --");
        System.out.println("Request URI: " + httpServletRequest.getRequestURI());
        Enumeration<String> headerNames = httpServletRequest.getHeaderNames();
        ArrayList<String> list = Collections.list(headerNames);
        System.out.println("Request headers: " + list.size());
        list.forEach(h -> System.out.println(h + " = " + httpServletRequest.getHeader(h)));
    }

    private void printServletContextInfo() {
        System.out.println("-- Servlet Context --");
        System.out.println("Context path: " + servletContext.getContextPath());
        System.out.println("Server info: " + servletContext.getServerInfo());
        Enumeration<String> attributeNames = servletContext.getAttributeNames();
        ArrayList<String> list = Collections.list(attributeNames);
        System.out.println("Context attributes: " + list.size());
        System.out.println("Session Tracking modes: " + servletContext.getDefaultSessionTrackingModes());
    }

    private void printServletConfigInfo() {
        System.out.println("-- Servlet Config Params --");
        Enumeration<String> initParameterNames = servletConfig.getInitParameterNames();
        ArrayList<String> list = Collections.list(initParameterNames);
        System.out.println("Init params: " + list.size());
        list.forEach(n -> System.out.println(n + " = " + servletConfig.getInitParameter(n)));
        System.out.println("Servlet name: " + servletConfig.getServletName());
    }
}